==> form-dinamico-react-render-0.6.3.tgz: package/es/components/FileGrid.js <==
import React from 'react';

import { withStyles } from '@material-ui/core/styles';

import GridList from '@material-ui/core/GridList';
import GridListTile from '@material-ui/core/GridListTile';
import GridListTileBar from '@material-ui/core/GridListTileBar';
import IconButton from '@material-ui/core/IconButton';

import DeleteIcon from '@material-ui/icons/Delete';

var fileGridStyles = function fileGridStyles(theme) {
    return {
        container: {
            display: 'flex',
            flexWrap: 'wrap',
            justifyContent: 'space-around',
            overflow: 'hidden',
            background: theme.palette.background.paper
        },
        gridList: {}
    };
};

function FileGrid(_ref) {
    var classes = _ref.classes,
        files = _ref.files,
        onDeleteClick = _ref.onDeleteClick;


    var handleDownload = function handleDownload(file) {
        return function () {
            file.link && window.open(file.link, 'blank');
        };
    };

    return React.createElement(
        'div',
        { className: classes.container },
        React.createElement(
            GridList,
            { className: classes.gridList },
            files.map(function (file, index) {
                return React.createElement(
                    GridListTile,
                    {
                        key: index,
                        onClick: handleDownload(file)
                    },
                    React.createElement('img', {
                        src: file.preview ? file.preview : file.link,
                        alt: file.name
                    }),
                    React.createElement(GridListTileBar, {
                        title: file.name,
                        subtitle: React.createElement(
                            'span',
                            null,
                            file.length + ' bytes'
                        ),
                        actionIcon: React.createElement(
                            IconButton,
                            { onClick: function onClick() {
                                    return onDeleteClick(file, index);
                                } },
                            React.createElement(DeleteIcon, { color: 'disabled' })
                        )
                    })
                );
            })
        )
    );
}

export default withStyles(fileGridStyles)(FileGrid);

==> form-dinamico-react-render-0.6.4.tgz: package/es/components/FileGrid.js <==
import React from 'react';

import { withStyles } from '@material-ui/core/styles';

import GridList from '@material-ui/core/GridList';
import GridListTile from '@material-ui/core/GridListTile';
import GridListTileBar from '@material-ui/core/GridListTileBar';
import IconButton from '@material-ui/core/IconButton';

import DeleteIcon from '@material-ui/icons/Delete';

var fileGridStyles = function fileGridStyles(theme) {
    return {
        container: {
            display: 'flex',
            flexWrap: 'wrap',
            justifyContent: 'space-around',
            overflow: 'hidden',
            background: theme.palette.background.paper
        },
        gridList: {}
    };
};

function FileGrid(_ref) {
    var classes = _ref.classes,
        files = _ref.files,
        onDeleteClick = _ref.onDeleteClick;


    var handleDownload = function handleDownload(file) {
        return function () {
            file.link && window.open(file.link, 'blank');
        };
    };

    return React.createElement(
        'div',
        { className: classes.container },
        React.createElement(
            GridList,
            { className: classes.gridList },
            files.map(function (file, index) {
                return React.createElement(
                    GridListTile,
                    { key: index },
                    React.createElement('img', {
                        src: file.preview ? file.preview : file.link,
                        alt: file.name
                    }),
                    React.createElement(GridListTileBar, {
                        onClick: handleDownload(file),
                        title: file.name,
                        subtitle: React.createElement(
                            'span',
                            null,
                            file.length + ' bytes'
                        ),
                        actionIcon: React.createElement(
                            IconButton,
                            { onClick: function onClick() {
                                    return onDeleteClick(file, index);
                                } },
                            React.createElement(DeleteIcon, { color: 'disabled' })
                        )
                    })
                );
            })
        )
    );
}

export default withStyles(fileGridStyles)(FileGrid);
